# How to contribute to this repo

We love your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

- Reporting a bug
- Proposing new features
- Discussing the current state of the code
- Submitting a fix

This is how you should do it:

Use our [issue list](../../issues) to report a **bug** or **propose a new feature**, including

### Reporting a **bug report**  
- A quick summary and/or background
- Steps to reproduce
- What actually happens

### Adding a **feature request**  
- Brief description of the feature
- What problem/issue will this solve
- A sort of Definition of Done - "How should it look when finished"

### When submitting a fix using a Pull Request (PR)  
- Fork this repository from GitHub  
- After you have made the changes, create a pull request (PR)  

We will review the pull request and if it is appropriate and there are no clashes or vulnerabilities, it will be merged to the main code.